@@ -19,7 +19,7 @@ def _get_types(ops, initdtype):
         cur = {}
         types = op.types
         for in_type, out_type in prev.items():
-            if out_type not in types:  # pragma: no cover
+            if out_type not in types:  # pragma: no cover (safety)
                 continue
             cur[in_type] = types[out_type]
         prev = cur
@@ -63,7 +63,7 @@ class Aggregator:
                 if finalize is not None:
                     types.append(finalize)
                 initval = self._initval
-            else:  # pragma: no cover
+            else:  # pragma: no cover (sanity)
                 raise TypeError("types must be provided for composite and custom aggregators")
         self._types_orig = types
         self._types = None
@@ -112,23 +112,21 @@ class Aggregator:
                     "rowwise and columnwise arguments should not be used with Vector input"
                 )
             return val.reduce(self)
-        elif typ in {Matrix, TransposedMatrix}:
+        if typ in {Matrix, TransposedMatrix}:
             if rowwise:
                 if columnwise:
                     raise ValueError("rowwise and columnwise arguments cannot both be True")
                 return val.reduce_rowwise(self)
-            elif columnwise:
+            if columnwise:
                 return val.reduce_columnwise(self)
-            else:
-                return val.reduce_scalar(self)
-        else:
-            raise TypeError(
-                f"Bad type when calling {self!r}.\n"
-                "    - Expected type: Vector, Matrix, TransposedMatrix.\n"
-                f"    - Got: {type(val)}.\n"
-                "Calling an Aggregator is syntactic sugar for calling reduce methods.  "
-                f"For example, `A.reduce_scalar({self!r})` is the same as `{self!r}(A)`."
-            )
+            return val.reduce_scalar(self)
+        raise TypeError(
+            f"Bad type when calling {self!r}.\n"
+            "    - Expected type: Vector, Matrix, TransposedMatrix.\n"
+            f"    - Got: {type(val)}.\n"
+            "Calling an Aggregator is syntactic sugar for calling reduce methods.  "
+            f"For example, `A.reduce_scalar({self!r})` is the same as `{self!r}(A)`."
+        )
 
 
 class TypedAggregator:
@@ -523,7 +521,7 @@ def _argminmax(agg, updater, expr, *, in_composite, monoid):
             row_semiring=semiring.min_firsti,
             col_semiring=semiring.min_secondi,
         )
-    elif expr.cfunc_name.startswith("GrB_Vector_reduce"):
+    if expr.cfunc_name.startswith("GrB_Vector_reduce"):
         return _argminmaxij(
             agg,
             updater,
@@ -533,10 +531,9 @@ def _argminmax(agg, updater, expr, *, in_composite, monoid):
             row_semiring=semiring.min_firsti,
             col_semiring=semiring.min_secondi,
         )
-    elif expr.cfunc_name.startswith("GrB_Matrix_reduce"):
+    if expr.cfunc_name.startswith("GrB_Matrix_reduce"):
         raise ValueError(f"Aggregator {agg.name} may not be used with Matrix.reduce_scalar.")
-    else:
-        raise NotImplementedError(f"{agg.name} with {expr.cfunc_name}")
+    raise NotImplementedError(f"{agg.name} with {expr.cfunc_name}")
 
 
 # These "do the right thing", but don't work with `reduce_scalar`
@@ -560,10 +557,10 @@ def _first_last(agg, updater, expr, *, in_composite, semiring_):
         init = expr._new_vector(bool, size=A._ncols)
         init[...] = False  # O(1) dense vector in SuiteSparse 5
         step1 = semiring_(A @ init).new()
-        Is, Js = step1.to_values()
+        Is, Js = step1.to_coo()
 
         Matrix_ = type(expr._new_matrix(bool))
-        P = Matrix_.from_values(Js, Is, 1, nrows=A._ncols, ncols=A._nrows)
+        P = Matrix_.from_coo(Js, Is, 1, nrows=A._ncols, ncols=A._nrows)
         mask = step1.diag()
         result = semiring.any_first(A @ P).new(mask=mask.S).diag()
 
