@@ -12,6 +12,7 @@ from .expr import _ALL_INDICES, AmbiguousAssignOrExtract, IndexerResolver, Updat
 from .mask import Mask, StructuralMask, ValueMask
 from .operator import UNKNOWN_OPCLASS, find_opclass, get_semiring, get_typed_op, op_from_string
 from .scalar import (
+    _COMPLETE,
     _MATERIALIZE,
     Scalar,
     ScalarExpression,
@@ -54,6 +55,17 @@ def _v_union_m(updater, left, right, left_default, right_default, op):
     updater << temp.ewise_union(right, op, left_default=left_default, right_default=right_default)
 
 
+def _v_union_v(updater, left, right, left_default, right_default, op, dtype):
+    mask = updater.kwargs.get("mask")
+    new_left = left.dup(dtype, clear=True)
+    new_left(mask=mask) << binary.second(right, left_default)
+    new_left(mask=mask) << binary.first(left | new_left)
+    new_right = right.dup(dtype, clear=True)
+    new_right(mask=mask) << binary.second(left, right_default)
+    new_right(mask=mask) << binary.first(right | new_right)
+    updater << op(new_left & new_right)
+
+
 def _reposition(updater, indices, chunk):
     updater[indices] = chunk
 
@@ -578,8 +590,15 @@ class Vector(BaseType):
         call("GrB_Matrix_diag", [_Pointer(rv), self, k])
         return rv
 
-    def wait(self):
-        """Wait for a computation to complete.
+    def wait(self, how="materialize"):
+        """Wait for a computation to complete or establish a "happens-before" relation
+
+        Parameters
+        ----------
+        how : {"materialize", "complete"}
+            "materialize" fully computes an object.
+            "complete" establishes a "happens-before" relation useful with multi-threading.
+            See GraphBLAS documentation for more details.
 
         In `non-blocking mode <../user_guide/init.html#graphblas-modes>`__,
         the computations may be delayed and not yet safe to use by multiple threads.
@@ -587,8 +606,14 @@ class Vector(BaseType):
 
         Has no effect in `blocking mode <../user_guide/init.html#graphblas-modes>`__.
         """
-        # TODO: expose COMPLETE or MATERIALIZE options to the user
-        call("GrB_Vector_wait", [self, _MATERIALIZE])
+        how = how.lower()
+        if how == "materialize":
+            mode = _MATERIALIZE
+        elif how == "complete":
+            mode = _COMPLETE
+        else:
+            raise ValueError(f'`how` argument must be "materialize" or "complete"; got {how!r}')
+        call("GrB_Vector_wait", [self, mode])
 
     def get(self, index, default=None):
         """Get an element at ``index`` as a Python scalar.
@@ -978,13 +1003,14 @@ class Vector(BaseType):
             )
         else:
             dtype = unify(scalar_dtype, nonscalar_dtype, is_left_scalar=True)
-            new_left = other.dup(dtype, clear=True)
-            new_left(other.S) << left
-            new_left(self.S) << self
-            new_right = self.dup(dtype, clear=True)
-            new_right(self.S) << right
-            new_right(other.S) << other
-            expr = op(new_left & new_right)
+            expr = VectorExpression(
+                method_name,
+                None,
+                [self, left, other, right, _v_union_v, (self, other, left, right, op, dtype)],
+                expr_repr=expr_repr,
+                size=self._size,
+                op=op,
+            )
         if self._size != other._size:
             expr.new(name="")  # incompatible shape; raise now
         return expr
