@@ -4,19 +4,9 @@ import numpy as np
 import pytest
 
 import graphblas as gb
-from graphblas import (
-    agg,
-    binary,
-    dtypes,
-    indexunary,
-    lib,
-    monoid,
-    op,
-    operator,
-    select,
-    semiring,
-    unary,
-)
+from graphblas import agg, binary, dtypes, indexunary, monoid, op, select, semiring, unary
+from graphblas.core import lib, operator
+from graphblas.core.operator import BinaryOp, IndexUnaryOp, Monoid, Semiring, UnaryOp, get_semiring
 from graphblas.dtypes import (
     BOOL,
     FP32,
@@ -31,7 +21,6 @@ from graphblas.dtypes import (
     UINT64,
 )
 from graphblas.exceptions import DomainMismatch, UdfParseError
-from graphblas.operator import BinaryOp, IndexUnaryOp, Monoid, Semiring, UnaryOp, get_semiring
 
 if dtypes._supports_complex:
     from graphblas.dtypes import FC32, FC64
@@ -129,6 +118,7 @@ def test_get_typed_op():
     assert operator.get_typed_op("+", dtypes.FP64, kind="monoid") is monoid.plus["FP64"]
     assert operator.get_typed_op("+[int64]", dtypes.FP64, kind="monoid") is monoid.plus["INT64"]
     assert operator.get_typed_op("+.*", dtypes.FP64, kind="semiring") is semiring.plus_times["FP64"]
+    assert operator.get_typed_op("row<=", dtypes.INT64, kind="select") is select.rowle["INT64"]
     with pytest.raises(ValueError, match="Unable to get op from string"):
         operator.get_typed_op("+", dtypes.FP64)
     assert (
@@ -146,7 +136,7 @@ def test_get_typed_op():
 
 def test_unaryop_udf():
     def plus_one(x):
-        return x + 1  # pragma: no cover
+        return x + 1  # pragma: no cover (numba)
 
     unary.register_new("plus_one", plus_one)
     assert hasattr(unary, "plus_one")
@@ -168,9 +158,9 @@ def test_unaryop_udf():
     if dtypes._supports_complex:
         comp_set.update({FC32, FC64})
     assert set(unary.plus_one.types) == comp_set
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     v << v.apply(unary.plus_one)
-    result = Vector.from_values([0, 1, 3], [2, 3, -3], dtype=dtypes.INT32)
+    result = Vector.from_coo([0, 1, 3], [2, 3, -3], dtype=dtypes.INT32)
     assert v.isequal(result)
     assert "INT8" in unary.plus_one
     assert INT8 in unary.plus_one.types
@@ -188,19 +178,19 @@ def test_unaryop_udf():
 def test_unaryop_parameterized():
     def plus_x(x=0):
         def inner(val):
-            return val + x  # pragma: no cover
+            return val + x  # pragma: no cover (numba)
 
         return inner
 
     op = UnaryOp.register_anonymous(plus_x, parameterized=True)
     assert not op.is_positional
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     v0 = v.apply(op).new()
     assert v.isequal(v0, check_dtype=True)
     v0 = v.apply(op(0)).new()
     assert v.isequal(v0, check_dtype=True)
     v10 = v.apply(op(x=10)).new()
-    r10 = Vector.from_values([0, 1, 3], [11, 12, 6], dtype=dtypes.INT32)
+    r10 = Vector.from_coo([0, 1, 3], [11, 12, 6], dtype=dtypes.INT32)
     assert r10.isequal(v10, check_dtype=True)
     UnaryOp._initialize()  # no-op
     UnaryOp.register_new("plus_x_parameterized", plus_x, parameterized=True)
@@ -213,7 +203,7 @@ def test_unaryop_parameterized():
 def test_binaryop_parameterized():
     def plus_plus_x(x=0):
         def inner(left, right):
-            return left + right + x  # pragma: no cover
+            return left + right + x  # pragma: no cover (numba)
 
         return inner
 
@@ -221,15 +211,15 @@ def test_binaryop_parameterized():
     assert not op.is_positional
     assert op.monoid is None
     assert op(1).monoid is None
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     v0 = v.ewise_mult(v, op).new()
-    r0 = Vector.from_values([0, 1, 3], [2, 4, -8], dtype=dtypes.INT32)
+    r0 = Vector.from_coo([0, 1, 3], [2, 4, -8], dtype=dtypes.INT32)
     assert v0.isequal(r0, check_dtype=True)
     v1 = v.ewise_add(v, op(1)).new()
-    r1 = Vector.from_values([0, 1, 3], [3, 5, -7], dtype=dtypes.INT32)
+    r1 = Vector.from_coo([0, 1, 3], [3, 5, -7], dtype=dtypes.INT32)
     assert v1.isequal(r1, check_dtype=True)
 
-    w = Vector.from_values([0, 0, 1, 3], [1, 0, 2, -4], dtype=dtypes.INT32, dup_op=op)
+    w = Vector.from_coo([0, 0, 1, 3], [1, 0, 2, -4], dtype=dtypes.INT32, dup_op=op)
     assert v.isequal(w, check_dtype=True)
     with pytest.raises(TypeError, match="Monoid"):
         assert v.reduce(op).new() == -1
@@ -246,9 +236,9 @@ def test_binaryop_parameterized():
     x = x.ewise_mult(x, op(1)).new()
     assert v.isequal(x)
 
-    assert v.isequal(Vector.from_values([0, 1, 3], [19, 35, -61], dtype=dtypes.INT32))
+    assert v.isequal(Vector.from_coo([0, 1, 3], [19, 35, -61], dtype=dtypes.INT32))
     v11 = v.apply(op(1), left=10).new()
-    r11 = Vector.from_values([0, 1, 3], [30, 46, -50], dtype=dtypes.INT32)
+    r11 = Vector.from_coo([0, 1, 3], [30, 46, -50], dtype=dtypes.INT32)
     # Should we check for dtype here?
     # Is it okay if the literal scalar is an INT64, which causes the output to default to INT64?
     assert v11.isequal(r11, check_dtype=False)
@@ -257,10 +247,14 @@ def test_binaryop_parameterized():
         BinaryOp.register_new("bad", object())
     assert not hasattr(binary, "bad")
     with pytest.raises(UdfParseError, match="Unable to parse function using Numba"):
-        BinaryOp.register_new("bad", lambda x, y: v)
+
+        def bad(x, y):  # pragma: no cover (numba)
+            return v
+
+        BinaryOp.register_new("bad", bad)
 
     def my_add(x, y):
-        return x + y  # pragma: no cover
+        return x + y  # pragma: no cover (numba)
 
     op = BinaryOp.register_anonymous(my_add)
     assert op.name == "my_add"
@@ -270,7 +264,7 @@ def test_binaryop_parameterized():
 def test_monoid_parameterized():
     def plus_plus_x(x=0):
         def inner(left, right):
-            return left + right + x  # pragma: no cover
+            return left + right + x  # pragma: no cover (numba)
 
         return inner
 
@@ -278,9 +272,9 @@ def test_monoid_parameterized():
 
     # signatures must match
     with pytest.raises(ValueError, match="Signatures"):
-        Monoid.register_anonymous(bin_op, lambda x: -x)  # pragma: no cover
+        Monoid.register_anonymous(bin_op, lambda x: -x)  # pragma: no cover (numba)
     with pytest.raises(ValueError, match="Signatures"):
-        Monoid.register_anonymous(bin_op, lambda y=0: -y)  # pragma: no cover
+        Monoid.register_anonymous(bin_op, lambda y=0: -y)  # pragma: no cover (numba)
     with pytest.raises(TypeError, match="binaryop must be parameterized"):
         operator.ParameterizedMonoid("bad_monoid", binary.plus, 0)
 
@@ -302,25 +296,25 @@ def test_monoid_parameterized():
     assert bin_op1.monoid is None
 
     assert monoid.name == "my_monoid"
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     v0 = v.ewise_add(v, monoid).new()
-    r0 = Vector.from_values([0, 1, 3], [2, 4, -8], dtype=dtypes.INT32)
+    r0 = Vector.from_coo([0, 1, 3], [2, 4, -8], dtype=dtypes.INT32)
     assert v0.isequal(r0, check_dtype=True)
     v1 = v.ewise_mult(v, monoid(1)).new()
-    r1 = Vector.from_values([0, 1, 3], [3, 5, -7], dtype=dtypes.INT32)
+    r1 = Vector.from_coo([0, 1, 3], [3, 5, -7], dtype=dtypes.INT32)
     assert v1.isequal(r1, check_dtype=True)
 
     assert v.reduce(monoid).new() == -1
     assert v.reduce(monoid(1)).new() == 1
     # with pytest.raises(TypeError, match="BinaryOp"):  # NOW OKAY
-    w1 = Vector.from_values([0, 0, 1, 3], [1, 0, 2, -4], dtype=dtypes.INT32, dup_op=monoid)
-    w2 = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    w1 = Vector.from_coo([0, 0, 1, 3], [1, 0, 2, -4], dtype=dtypes.INT32, dup_op=monoid)
+    w2 = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     assert w1.isequal(w2)
 
     # identity may be a value
     def logaddexp(base):
         def inner(x, y):
-            return np.log(base**x + base**y) / np.log(base)  # pragma: no cover
+            return np.log(base**x + base**y) / np.log(base)  # pragma: no cover (numba)
 
         return inner
 
@@ -329,7 +323,11 @@ def test_monoid_parameterized():
     Monoid.register_new("_user_defined_monoid", bin_op, -np.inf)
     monoid = gb.monoid._user_defined_monoid
     fv2 = fv.ewise_mult(fv, monoid(2)).new()
-    plus1 = UnaryOp.register_anonymous(lambda x: x + 1)
+
+    def plus1(x):  # pragma: no cover (numba)
+        return x + 1
+
+    plus1 = UnaryOp.register_anonymous(plus1)
     expected = fv.apply(plus1).new()
     assert fv2.isclose(expected, check_dtype=True)
     with pytest.raises(TypeError, match="must be a BinaryOp"):
@@ -337,7 +335,7 @@ def test_monoid_parameterized():
 
     def plus_times_x(x=0):
         def inner(left, right):
-            return (left + right) * x  # pragma: no cover
+            return (left + right) * x  # pragma: no cover (numba)
 
         return inner
 
@@ -356,7 +354,7 @@ def test_monoid_parameterized():
 def test_semiring_parameterized():
     def plus_plus_x(x=0):
         def inner(left, right):
-            return left + right + x  # pragma: no cover
+            return left + right + x  # pragma: no cover (numba)
 
         return inner
 
@@ -372,42 +370,42 @@ def test_semiring_parameterized():
     assert not mysemiring.is_positional
     assert mysemiring.name == "my_semiring"
 
-    A = Matrix.from_values([0, 0, 1, 1], [0, 1, 0, 1], [1, 2, 3, 4])
-    x = Vector.from_values([0, 1], [10, 20])
+    A = Matrix.from_coo([0, 0, 1, 1], [0, 1, 0, 1], [1, 2, 3, 4])
+    x = Vector.from_coo([0, 1], [10, 20])
 
     y = A.mxv(x, mysemiring).new()
     assert y.isequal(A.mxv(x, semiring.plus_plus).new())
     assert y.isequal(x.vxm(A.T, semiring.plus_plus).new())
-    assert y.isequal(Vector.from_values([0, 1], [33, 37]))
+    assert y.isequal(Vector.from_coo([0, 1], [33, 37]))
 
     y = A.mxv(x, mysemiring(1)).new()
-    assert y.isequal(Vector.from_values([0, 1], [36, 40]))  # three extra pluses
+    assert y.isequal(Vector.from_coo([0, 1], [36, 40]))  # three extra pluses
 
     y = x.vxm(A.T, mysemiring(1)).new()  # same as previous
-    assert y.isequal(Vector.from_values([0, 1], [36, 40]))
+    assert y.isequal(Vector.from_coo([0, 1], [36, 40]))
 
     y = x.vxm(A.T, mysemiring).new()
-    assert y.isequal(Vector.from_values([0, 1], [33, 37]))
+    assert y.isequal(Vector.from_coo([0, 1], [33, 37]))
 
     B = A.mxm(A, mysemiring).new()
     assert B.isequal(A.mxm(A, semiring.plus_plus).new())
-    assert B.isequal(Matrix.from_values([0, 0, 1, 1], [0, 1, 0, 1], [7, 9, 11, 13]))
+    assert B.isequal(Matrix.from_coo([0, 0, 1, 1], [0, 1, 0, 1], [7, 9, 11, 13]))
 
     B = A.mxm(A, mysemiring(1)).new()  # three extra pluses
-    assert B.isequal(Matrix.from_values([0, 0, 1, 1], [0, 1, 0, 1], [10, 12, 14, 16]))
+    assert B.isequal(Matrix.from_coo([0, 0, 1, 1], [0, 1, 0, 1], [10, 12, 14, 16]))
 
     with pytest.raises(TypeError, match="Expected type: BinaryOp, Monoid"):
         A.ewise_add(A, mysemiring)
 
     # mismatched signatures.
-    def other_binary(y=0):  # pragma: no cover
+    def other_binary(y=0):  # pragma: no cover (numba)
         def inner(left, right):
             return left + right - y
 
         return inner
 
     def other_identity(y=0):
-        return x  # pragma: no cover
+        return x  # pragma: no cover (numba)
 
     other_op = BinaryOp.register_anonymous(other_binary, parameterized=True)
     other_monoid = Monoid.register_anonymous(other_op, other_identity)
@@ -449,15 +447,13 @@ def test_semiring_parameterized():
         operator.ParameterizedSemiring("bad_semiring", monoid.plus, monoid.plus)
 
     # While we're here, let's check misc Matrix operations
-    Adup = Matrix.from_values([0, 0, 0, 1, 1], [0, 0, 1, 0, 1], [100, 1, 2, 3, 4], dup_op=bin_op)
-    Adup2 = Matrix.from_values(
-        [0, 0, 0, 1, 1], [0, 0, 1, 0, 1], [100, 1, 2, 3, 4], dup_op=binary.plus
-    )
+    Adup = Matrix.from_coo([0, 0, 0, 1, 1], [0, 0, 1, 0, 1], [100, 1, 2, 3, 4], dup_op=bin_op)
+    Adup2 = Matrix.from_coo([0, 0, 0, 1, 1], [0, 0, 1, 0, 1], [100, 1, 2, 3, 4], dup_op=binary.plus)
     assert Adup.isequal(Adup2)
 
     def plus_x(x=0):
         def inner(y):
-            return x + y  # pragma: no cover
+            return x + y  # pragma: no cover (numba)
 
         return inner
 
@@ -484,7 +480,7 @@ def test_semiring_parameterized():
 def test_unaryop_udf_bool_result():
     # numba has trouble compiling this, but we have a work-around
     def is_positive(x):
-        return x > 0  # pragma: no cover
+        return x > 0  # pragma: no cover (numba)
 
     UnaryOp.register_new("is_positive", is_positive)
     assert hasattr(unary, "is_positive")
@@ -501,15 +497,15 @@ def test_unaryop_udf_bool_result():
         FP64,
         BOOL,
     }
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     w = v.apply(unary.is_positive).new()
-    result = Vector.from_values([0, 1, 3], [True, True, False], dtype=dtypes.BOOL)
+    result = Vector.from_coo([0, 1, 3], [True, True, False], dtype=dtypes.BOOL)
     assert w.isequal(result)
 
 
 def test_binaryop_udf():
     def times_minus_sum(x, y):
-        return x * y - (x + y)  # pragma: no cover
+        return x * y - (x + y)  # pragma: no cover (numba)
 
     BinaryOp.register_new("bin_test_func", times_minus_sum)
     assert hasattr(binary, "bin_test_func")
@@ -529,16 +525,16 @@ def test_binaryop_udf():
     if dtypes._supports_complex:
         comp_set.update({FC32, FC64})
     assert set(binary.bin_test_func.types) == comp_set
-    v1 = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
-    v2 = Vector.from_values([0, 2, 3], [2, 3, 7], dtype=dtypes.INT32)
+    v1 = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v2 = Vector.from_coo([0, 2, 3], [2, 3, 7], dtype=dtypes.INT32)
     w = v1.ewise_add(v2, binary.bin_test_func).new()
-    result = Vector.from_values([0, 1, 2, 3], [-1, 2, 3, -31], dtype=dtypes.INT32)
+    result = Vector.from_coo([0, 1, 2, 3], [-1, 2, 3, -31], dtype=dtypes.INT32)
     assert w.isequal(result)
 
 
 def test_monoid_udf():
     def plus_plus_one(x, y):
-        return x + y + 1  # pragma: no cover
+        return x + y + 1  # pragma: no cover (numba)
 
     BinaryOp.register_new("plus_plus_one", plus_plus_one)
     Monoid.register_new("plus_plus_one", binary.plus_plus_one, -1)
@@ -558,10 +554,10 @@ def test_monoid_udf():
     if dtypes._supports_complex:
         comp_set.update({FC32, FC64})
     assert set(monoid.plus_plus_one.types) == comp_set
-    v1 = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
-    v2 = Vector.from_values([0, 2, 3], [2, 3, 7], dtype=dtypes.INT32)
+    v1 = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v2 = Vector.from_coo([0, 2, 3], [2, 3, 7], dtype=dtypes.INT32)
     w = v1.ewise_add(v2, monoid.plus_plus_one).new()
-    result = Vector.from_values([0, 1, 2, 3], [4, 2, 3, 4], dtype=dtypes.INT32)
+    result = Vector.from_coo([0, 1, 2, 3], [4, 2, 3, 4], dtype=dtypes.INT32)
     assert w.isequal(result)
 
     with pytest.raises(DomainMismatch):
@@ -572,40 +568,40 @@ def test_monoid_udf():
 
 def test_semiring_udf():
     def plus_plus_two(x, y):
-        return x + y + 2  # pragma: no cover
+        return x + y + 2  # pragma: no cover (numba)
 
     BinaryOp.register_new("plus_plus_two", plus_plus_two)
     Semiring.register_new("extra_twos", monoid.plus, binary.plus_plus_two)
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
-    A = Matrix.from_values(
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    A = Matrix.from_coo(
         [0, 0, 0, 0, 3, 3, 3, 3],
         [0, 1, 2, 3, 0, 1, 2, 3],
         [2, 3, 4, 5, 6, 7, 8, 9],
         dtype=dtypes.INT32,
     )
     w = v.vxm(A, semiring.extra_twos).new()
-    result = Vector.from_values([0, 1, 2, 3], [9, 11, 13, 15], dtype=dtypes.INT32)
+    result = Vector.from_coo([0, 1, 2, 3], [9, 11, 13, 15], dtype=dtypes.INT32)
     assert w.isequal(result)
 
 
 def test_binary_updates():
     assert not hasattr(binary, "div")
     assert binary.cdiv["INT64"].gb_obj == lib.GrB_DIV_INT64
-    vec1 = Vector.from_values([0], [1], dtype=dtypes.INT64)
-    vec2 = Vector.from_values([0], [2], dtype=dtypes.INT64)
+    vec1 = Vector.from_coo([0], [1], dtype=dtypes.INT64)
+    vec2 = Vector.from_coo([0], [2], dtype=dtypes.INT64)
     result = vec1.ewise_mult(vec2, binary.truediv).new()
-    assert result.isclose(Vector.from_values([0], [0.5], dtype=dtypes.FP64), check_dtype=True)
-    vec4 = Vector.from_values([0], [-3], dtype=dtypes.INT64)
+    assert result.isclose(Vector.from_coo([0], [0.5], dtype=dtypes.FP64), check_dtype=True)
+    vec4 = Vector.from_coo([0], [-3], dtype=dtypes.INT64)
     result2 = vec4.ewise_mult(vec2, binary.cdiv).new()
-    assert result2.isequal(Vector.from_values([0], [-1], dtype=dtypes.INT64), check_dtype=True)
+    assert result2.isequal(Vector.from_coo([0], [-1], dtype=dtypes.INT64), check_dtype=True)
     result3 = vec4.ewise_mult(vec2, binary.floordiv).new()
-    assert result3.isequal(Vector.from_values([0], [-2], dtype=dtypes.INT64), check_dtype=True)
+    assert result3.isequal(Vector.from_coo([0], [-2], dtype=dtypes.INT64), check_dtype=True)
 
 
 @pytest.mark.slow
 def test_nested_names():
     def plus_three(x):
-        return x + 3  # pragma: no cover
+        return x + 3  # pragma: no cover (numba)
 
     UnaryOp.register_new("incrementers.plus_three", plus_three)
     assert hasattr(unary, "incrementers")
@@ -628,23 +624,23 @@ def test_nested_names():
         comp_set.update({FC32, FC64})
     assert set(unary.incrementers.plus_three.types) == comp_set
 
-    v = Vector.from_values([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
+    v = Vector.from_coo([0, 1, 3], [1, 2, -4], dtype=dtypes.INT32)
     v << v.apply(unary.incrementers.plus_three)
-    result = Vector.from_values([0, 1, 3], [4, 5, -1], dtype=dtypes.INT32)
+    result = Vector.from_coo([0, 1, 3], [4, 5, -1], dtype=dtypes.INT32)
     assert v.isequal(result), v
 
     def plus_four(x):
-        return x + 4  # pragma: no cover
+        return x + 4  # pragma: no cover (numba)
 
     UnaryOp.register_new("incrementers.plus_four", plus_four)
     assert hasattr(unary.incrementers, "plus_four")
     assert hasattr(op.incrementers, "plus_four")  # Also save it to `graphblas.op`!
     v << v.apply(unary.incrementers.plus_four)  # this is in addition to the plus_three earlier
-    result2 = Vector.from_values([0, 1, 3], [8, 9, 3], dtype=dtypes.INT32)
+    result2 = Vector.from_coo([0, 1, 3], [8, 9, 3], dtype=dtypes.INT32)
     assert v.isequal(result2), v
 
     def bad_will_overwrite_path(x):
-        return x + 7  # pragma: no cover
+        return x + 7  # pragma: no cover (numba)
 
     with pytest.raises(AttributeError):
         UnaryOp.register_new("incrementers", bad_will_overwrite_path)
@@ -674,14 +670,13 @@ def test_op_namespace():
         op.numpy.bad_attr
 
     # Make sure all have been initialized so `vars` below works
-    for key in list(op._delayed):  # pragma: no cover
+    for key in list(op._delayed):  # pragma: no cover (safety)
         getattr(op, key)
-    known_aliases = {"index", "indexle", "indexgt"}
     opnames = {
         key
         for key, val in vars(op).items()
         if isinstance(val, (operator.OpBase, operator.ParameterizedUdf))
-    } | known_aliases
+    }
     unarynames = {
         key
         for key, val in vars(unary).items()
@@ -716,11 +711,10 @@ def test_op_namespace():
     assert not binarynames - opnames, binarynames - opnames
     assert not monoidnames - opnames, monoidnames - opnames
     assert not semiringnames - opnames, semiringnames - opnames
-    assert not indexunarynames - opnames, indexunarynames - opnames
-    assert not selectnames - opnames, selectnames - opnames
-    assert not opnames - (
-        unarynames | binarynames | monoidnames | semiringnames | indexunarynames | selectnames
-    )
+    assert not opnames - (unarynames | binarynames | monoidnames | semiringnames)
+    # These are not part of the `op` namespace
+    assert indexunarynames - opnames == indexunarynames, indexunarynames - opnames
+    assert selectnames - opnames == selectnames, selectnames - opnames
 
 
 @pytest.mark.slow
@@ -736,7 +730,7 @@ def test_binaryop_attributes():
     assert binary.numpy.subtract.monoid is None
 
     def plus(x, y):
-        return x + y  # pragma: no cover
+        return x + y  # pragma: no cover (numba)
 
     op = BinaryOp.register_anonymous(plus, name="plus")
     assert op.monoid is None
@@ -777,7 +771,7 @@ def test_monoid_attributes():
     assert monoid.numpy.add.binaryop is binary.numpy.add
     assert monoid.numpy.add.identities == {typ: 0 for typ in monoid.numpy.add.types}
 
-    def plus(x, y):  # pragma: no cover
+    def plus(x, y):  # pragma: no cover (numba)
         return x + y
 
     binop = BinaryOp.register_anonymous(plus, name="plus")
@@ -814,7 +808,7 @@ def test_semiring_attributes():
     assert semiring.numpy.add_subtract.binaryop is binary.numpy.subtract
 
     def plus(x, y):
-        return x + y  # pragma: no cover
+        return x + y  # pragma: no cover (numba)
 
     binop = BinaryOp.register_anonymous(plus, name="plus")
     mymonoid = Monoid.register_anonymous(binop, 0, name="plus")
@@ -853,8 +847,8 @@ def test_binaryop_superset_monoids():
 
 def test_div_semirings():
     assert not hasattr(semiring, "plus_div")
-    A1 = Matrix.from_values([0, 1], [0, 0], [-1, -3])
-    A2 = Matrix.from_values([0, 1], [0, 0], [2, 2])
+    A1 = Matrix.from_coo([0, 1], [0, 0], [-1, -3])
+    A2 = Matrix.from_coo([0, 1], [0, 0], [2, 2])
     result = A1.T.mxm(A2, semiring.plus_cdiv).new()
     assert result[0, 0].new() == -1
     assert result.dtype == dtypes.INT64
@@ -882,7 +876,7 @@ def test_get_semiring():
         get_semiring(binary.plus, monoid.times)
 
     def myplus(x, y):
-        return x + y  # pragma: no cover
+        return x + y  # pragma: no cover (numba)
 
     binop = BinaryOp.register_anonymous(myplus, name="myplus")
     st = get_semiring(monoid.plus, binop)
@@ -1026,10 +1020,10 @@ def test_from_string():
 
 @pytest.mark.slow
 def test_lazy_op():
-    UnaryOp.register_new("lazy", lambda x: x, lazy=True)  # pragma: no branch
+    UnaryOp.register_new("lazy", lambda x: x, lazy=True)  # pragma: no branch (numba)
     assert isinstance(op.lazy, UnaryOp)
     assert isinstance(unary.lazy, UnaryOp)
-    BinaryOp.register_new("lazy", lambda x, y: x + y, lazy=True)  # pragma: no branch
+    BinaryOp.register_new("lazy", lambda x, y: x + y, lazy=True)  # pragma: no branch (numba)
     Monoid.register_new("lazy", "lazy", 0, lazy=True)
     assert isinstance(monoid.lazy, Monoid)
     assert isinstance(binary.lazy, BinaryOp)
@@ -1041,9 +1035,9 @@ def test_lazy_op():
     Semiring.register_new("lazy_lazy", monoid.lazy, binary.lazy, lazy=True)
     assert isinstance(semiring.lazy_lazy, Semiring)
     # numpy
-    UnaryOp.register_new("numpy.lazy", lambda x: x, lazy=True)  # pragma: no branch
+    UnaryOp.register_new("numpy.lazy", lambda x: x, lazy=True)  # pragma: no branch (numba)
     assert isinstance(unary.numpy.lazy, UnaryOp)
-    BinaryOp.register_new("numpy.lazy", lambda x, y: x + y, lazy=True)  # pragma: no branch
+    BinaryOp.register_new("numpy.lazy", lambda x, y: x + y, lazy=True)  # pragma: no branch (numba)
     Monoid.register_new("numpy.lazy", "numpy.lazy", 0, lazy=True)
     assert isinstance(monoid.numpy.lazy, Monoid)
     assert isinstance(binary.numpy.lazy, BinaryOp)
@@ -1056,7 +1050,7 @@ def test_lazy_op():
     Semiring.register_new("numpy.lazy_lazy", monoid.numpy.lazy, binary.numpy.lazy, lazy=True)
     assert isinstance(semiring.numpy.lazy_lazy, Semiring)
     # misc
-    UnaryOp.register_new("misc.lazy", lambda x: x, lazy=True)  # pragma: no branch
+    UnaryOp.register_new("misc.lazy", lambda x: x, lazy=True)  # pragma: no branch (numba)
     assert isinstance(unary.misc.lazy, UnaryOp)
     with pytest.raises(AttributeError):
         unary.misc.bad
@@ -1098,7 +1092,7 @@ def test_udt():
     w[:] = 1
 
     def _udt_identity(val):
-        return val  # pragma: no cover
+        return val  # pragma: no cover (numba)
 
     udt_identity = UnaryOp.register_new("udt_identity", _udt_identity, is_udt=True)
     assert udt in udt_identity
@@ -1115,27 +1109,27 @@ def test_udt():
         assert "badname" in udt_identity
 
     def _udt_getx(val):
-        return val["x"]  # pragma: no cover
+        return val["x"]  # pragma: no cover (numba)
 
     udt_getx = UnaryOp.register_anonymous(_udt_getx, "udt_getx", is_udt=True)
     assert udt in udt_getx
     result = v.apply(udt_getx).new()
-    expected = Vector.from_values([0, 1, 2], 0)
+    expected = Vector.from_coo([0, 1, 2], 0)
     assert result.isequal(expected)
 
-    def _udt_index(val, idx, _, thunk):
-        if idx == 0:  # pragma: no cover
+    def _udt_index(val, idx, _, thunk):  # pragma: no cover (numba)
+        if idx == 0:
             return thunk["y"]
-        return -thunk["y"]  # pragma: no cover
+        return -thunk["y"]
 
     _udt_index = IndexUnaryOp.register_anonymous(_udt_index, "_udt_index", is_udt=True)
     assert udt in _udt_index
     result = v.apply(_udt_index, 3).new()
-    expected = Vector.from_values([0, 1, 2], [3, -3, -3])
+    expected = Vector.from_coo([0, 1, 2], [3, -3, -3])
     assert result.isequal(expected)
 
     def _udt_first(x, y):
-        return x  # pragma: no cover
+        return x  # pragma: no cover (numba)
 
     udt_first = BinaryOp.register_anonymous(_udt_first, "udt_first", is_udt=True)
     assert udt in udt_first
@@ -1174,21 +1168,21 @@ def test_udt():
     assert result.isequal(expected)
 
     result = indexunary.rowindex(v).new()
-    assert result.isequal(Vector.from_values([0, 1, 2], [0, 1, 2]))
+    assert result.isequal(Vector.from_coo([0, 1, 2], [0, 1, 2]))
     result = select.rowle(v, 2).new()
     assert result.isequal(v)
 
     class BreakCompile:
         pass
 
-    def badfunc(x):  # pragma: no cover
+    def badfunc(x):  # pragma: no cover (numba)
         return BreakCompile(x)
 
     badunary = UnaryOp.register_anonymous(badfunc, is_udt=True)
     assert udt not in badunary
     assert int not in badunary
 
-    def badfunc(x, y):  # pragma: no cover
+    def badfunc(x, y):  # pragma: no cover (numba)
         return BreakCompile(x)
 
     badbinary = BinaryOp.register_anonymous(badfunc, is_udt=True)
@@ -1202,12 +1196,12 @@ def test_udt():
 
     assert binary.second[udt].type is udt
     assert binary.second[udt].type2 is udt
-    assert binary.second[udt, dtypes.INT8].type is dtypes.INT8  # ignore first arg
+    assert binary.second[udt, dtypes.INT8].type is udt
     assert binary.second[udt, dtypes.INT8].type2 is dtypes.INT8
-    assert semiring.any_second[udt, dtypes.INT8].type is dtypes.INT8  # ignore first arg
+    assert semiring.any_second[udt, dtypes.INT8].type is udt
     assert semiring.any_second[udt, dtypes.INT8].type2 is dtypes.INT8
     assert binary.first[udt, dtypes.INT8].type is udt
-    assert binary.first[udt, dtypes.INT8].type2 is dtypes.INT8  # include second arg!
+    assert binary.first[udt, dtypes.INT8].type2 is dtypes.INT8
     assert monoid.any[udt].type2 is udt
 
 
@@ -1224,7 +1218,7 @@ def test_semiring_commute_exists():
     for key in orig_semirings:
         val = getattr(semiring, key)
         commutes_to = val.commutes_to
-        if commutes_to is not None and commutes_to not in vals:  # pragma: no cover
+        if commutes_to is not None and commutes_to not in vals:  # pragma: no cover (debug)
             missing.add(commutes_to.name)
     if missing:
         raise AssertionError("Missing semirings: " + ", ".join(sorted(missing)))
@@ -1238,15 +1232,26 @@ def test_binaryop_commute_exists():
     for key in orig_binaryops:
         val = getattr(binary, key)
         commutes_to = val.commutes_to
-        if commutes_to is not None and commutes_to not in vals:  # pragma: no cover
+        if commutes_to is not None and commutes_to not in vals:  # pragma: no cover (debug)
             missing.add(commutes_to.name)
     if missing:
         raise AssertionError("Missing binaryops: " + ", ".join(sorted(missing)))
 
 
 def test_binom():
-    v = Vector.from_values([0, 1, 2], [3, 4, 5])
+    v = Vector.from_coo([0, 1, 2], [3, 4, 5])
     result = v.apply(binary.binom, 2).new()
-    expected = Vector.from_values([0, 1, 2], [3, 6, 10])
+    expected = Vector.from_coo([0, 1, 2], [3, 6, 10])
     assert result.isequal(expected)
     assert op.binom is binary.binom
+
+
+def test_builtins():
+    v1 = Vector.from_coo([0, 1, 2], [1, 2, 3])
+    v2 = Vector.from_coo([0, 1, 2], [3, 2, 1])
+    result = v1.ewise_mult(v2, min).new()
+    expected = Vector.from_coo([0, 1, 2], [1, 2, 1])
+    assert result.isequal(expected)
+    v1(max) << v2
+    expected = Vector.from_coo([0, 1, 2], [3, 2, 3])
+    assert v1.isequal(expected)
