@@ -9,39 +9,39 @@ except ImportError:
 
 
 @pytest.mark.skipif("not pg")
-def test_pygraphblas_matrix():  # pragma: no cover
+def test_pygraphblas_matrix():  # pragma: no cover (outdated)
     if gb.backend != "suitesparse":  # pragma: no cover
         return
     import pygraphblas as pg
 
-    A = gb.Matrix.from_values([0, 1], [0, 1], [0, 1])
+    A = gb.Matrix.from_coo([0, 1], [0, 1], [0, 1])
     pgA = A.to_pygraphblas()
     assert isinstance(pgA, pg.Matrix)
-    assert A.gb_obj is gb.ffi.NULL
+    assert A.gb_obj is gb.core.NULL
     pgA += 1
     A2 = gb.Matrix.from_pygraphblas(pgA)
-    assert A2.isequal(gb.Matrix.from_values([0, 1], [0, 1], [1, 2]))
+    assert A2.isequal(gb.Matrix.from_coo([0, 1], [0, 1], [1, 2]))
     assert A.dtype == A2.dtype
 
 
 @pytest.mark.skipif("not pg")
-def test_pygraphblas_vector():  # pragma: no cover
+def test_pygraphblas_vector():  # pragma: no cover (outdated)
     if gb.backend != "suitesparse":  # pragma: no cover
         return
     import pygraphblas as pg
 
-    v = gb.Vector.from_values([0, 2], [0, 1])
+    v = gb.Vector.from_coo([0, 2], [0, 1])
     pgv = v.to_pygraphblas()
     assert isinstance(pgv, pg.Vector)
-    assert v.gb_obj is gb.ffi.NULL
+    assert v.gb_obj is gb.core.NULL
     pgv += 1
     v2 = gb.Vector.from_pygraphblas(pgv)
-    assert v2.isequal(gb.Vector.from_values([0, 2], [1, 2]))
+    assert v2.isequal(gb.Vector.from_coo([0, 2], [1, 2]))
     assert v.dtype == v2.dtype
 
 
 @pytest.mark.skipif("not pg")
-def test_pygraphblas_scalar():  # pragma: no cover
+def test_pygraphblas_scalar():  # pragma: no cover (outdated)
     if gb.backend != "suitesparse":  # pragma: no cover
         return
     import pygraphblas as pg
